<?xml version="1.0" encoding="UTF-8"?>
<schema xmlns="http://purl.oclc.org/dsdl/schematron" 
        xmlns:cac="urn:oasis:names:specification:ubl:schema:xsd:CommonAggregateComponents-2"
        xmlns:cbc="urn:oasis:names:specification:ubl:schema:xsd:CommonBasicComponents-2"
        xmlns:cn="urn:oasis:names:specification:ubl:schema:xsd:CreditNote-2"
        xmlns:UBL="urn:oasis:names:specification:ubl:schema:xsd:Invoice-2"
		xmlns:u="utils" schemaVersion="iso"
		queryBinding="xslt2">

  <title>Rules for PL Accounting Note</title>
  
  <ns prefix="ext"
       uri="urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2"/>
  <ns prefix="cbc"
       uri="urn:oasis:names:specification:ubl:schema:xsd:CommonBasicComponents-2"/>
  <ns prefix="cac"
       uri="urn:oasis:names:specification:ubl:schema:xsd:CommonAggregateComponents-2"/>
  <ns prefix="qdt"
       uri="urn:oasis:names:specification:ubl:schema:xsd:QualifiedDataTypes-2"/>
  <ns prefix="udt"
       uri="urn:oasis:names:specification:ubl:schema:xsd:UnqualifiedDataTypes-2"/>
  <ns prefix="cn"
       uri="urn:oasis:names:specification:ubl:schema:xsd:CreditNote-2"/>
  <ns prefix="ubl"
       uri="urn:oasis:names:specification:ubl:schema:xsd:Invoice-2"/>
  <ns uri="http://www.w3.org/2001/XMLSchema" prefix="xs"/>
  <ns uri="utils" prefix="u"/>

  <!-- Parameters -->

  <let name="profile"
    value="
      if (/*/cbc:ProfileID and matches(normalize-space(/*/cbc:ProfileID), 'urn:fdc:www.efaktura.gov.pl:ver1.0:account_corr:ver1.0')) then
        tokenize(normalize-space(/*/cbc:ProfileID), ':')[7]
      else
        'Unknown'"/>
  <let name="supplierCountry"
    value="
      if (/*/cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme[cac:TaxScheme/cbc:ID = 'VAT']/substring(cbc:CompanyID, 1, 2)) then
        upper-case(normalize-space(/*/cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme[cac:TaxScheme/cbc:ID = 'VAT']/substring(cbc:CompanyID, 1, 2)))
      else
        if (/*/cac:TaxRepresentativeParty/cac:PartyTaxScheme[cac:TaxScheme/cbc:ID = 'VAT']/substring(cbc:CompanyID, 1, 2)) then
          upper-case(normalize-space(/*/cac:TaxRepresentativeParty/cac:PartyTaxScheme[cac:TaxScheme/cbc:ID = 'VAT']/substring(cbc:CompanyID, 1, 2)))
        else
          if (/*/cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cac:Country/cbc:IdentificationCode) then
            upper-case(normalize-space(/*/cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cac:Country/cbc:IdentificationCode))
          else
            'XX'"/>
  <!-- -->

  <let name="documentCurrencyCode" value="/*/cbc:DocumentCurrencyCode"/>

  <!-- Functions -->

  <function xmlns="http://www.w3.org/1999/XSL/Transform" name="u:slack" as="xs:boolean">
    <param name="exp" as="xs:decimal"/>
    <param name="val" as="xs:decimal"/>
    <param name="slack" as="xs:decimal"/>
    <value-of select="xs:decimal($exp + $slack) &gt;= $val and xs:decimal($exp - $slack) &lt;= $val"
    />
  </function>
  
  <function xmlns="http://www.w3.org/1999/XSL/Transform" name="u:mod11" as="xs:boolean">
    <param name="val"/>
    <variable name="length" select="string-length($val) - 1"/>
    <variable name="digits" select="reverse(for $i in string-to-codepoints(substring($val, 0, $length + 1)) return $i - 48)"/>
    <variable name="weightedSum" select="sum(for $i in (0 to $length - 1) return $digits[$i + 1] * (($i mod 6) + 2))"/>
    <value-of select="number($val) &gt; 0 and (11 - ($weightedSum mod 11)) mod 11 = number(substring($val, $length + 1, 1))"/>
  </function>
  
  <function xmlns="http://www.w3.org/1999/XSL/Transform" name="u:gln" as="xs:boolean">
    <param name="val"/>
    <variable name="length" select="string-length($val) - 1"/>
    <variable name="digits"
                select="reverse(for $i in string-to-codepoints(substring($val, 0, $length + 1)) return $i - 48)"/>
    <variable name="weightedSum"
                select="sum(for $i in (0 to $length - 1) return $digits[$i + 1] * (1 + ((($i + 1) mod 2) * 2)))"/>
    <value-of select="10 - ($weightedSum mod 10) = number(substring($val, $length + 1, 1))"/>
  </function>

   <!--Start pattern based on abstract model-->
  <pattern id="UBL-model">
      <rule context="cac:AccountingCustomerParty/cac:Party/cbc:EndpointID">
         <assert test="exists(@schemeID)" flag="fatal" id="PL-AN-016">[PL-AN-016]-The Buyer electronic address (BT-49) shall have a Scheme identifier.    </assert>
      </rule>
      <rule context="cac:AccountingCustomerParty/cac:Party/cac:PostalAddress">
         <assert test="(cac:Country/cbc:IdentificationCode) != ''"
                 flag="fatal"
                 id="PL-AN-010">[PL-AN-010]-The Buyer postal address shall contain a Buyer country code (BT-55).</assert>
      </rule>
      <rule context="cac:LegalMonetaryTotal">
         <assert test="exists(cbc:LineExtensionAmount)" flag="fatal" id="PL-AN-011">[PL-AN-011]-An Invoice shall have the Sum of Invoice line net amount (BT-106).</assert>
         <assert test="exists(cbc:PayableAmount)" flag="fatal" id="PL-AN-012">[PL-AN-012]-An Invoice shall have the Amount due for payment (BT-115).</assert>
         <assert test="(xs:decimal(cbc:LineExtensionAmount) = (round(sum(//cac:InvoiceLine/xs:decimal(cbc:LineExtensionAmount)) * 10 * 10) div 100)) or (xs:decimal(cbc:LineExtensionAmount) = (round(sum(//cac:CreditNoteLine/xs:decimal(cbc:LineExtensionAmount)) * 10 * 10) div 100))"
                 flag="fatal"
                 id="PL-AN-024">[PL-AN-024]-Sum of Invoice line net amount (BT-106) = Σ Invoice line net amount (BT-131).</assert>
         <assert test="string-length(substring-after(cbc:LineExtensionAmount,'.'))&lt;=2"
                 flag="fatal"
                 id="PL-AN-026">[PL-AN-026]-The allowed maximum number of decimals for the Sum of Invoice line net amount (BT-106) is 2.</assert>
         <assert test="string-length(substring-after(cbc:PayableAmount,'.'))&lt;=2"
                 flag="fatal"
                 id="BR-DEC-18">[BR-DEC-18]-The allowed maximum number of decimals for the Amount due for payment (BT-115) is 2.  </assert>
      </rule>
      <rule context="//cn:CreditNote">
         <assert test="(cbc:CustomizationID) != ''" flag="fatal" id="PL-AN-001">[PL-AN-001]-An Invoice shall have a Specification identifier (BT-24).   </assert>
         <assert test="(cbc:ID) !=''" flag="fatal" id="PL-AN-002">[PL-AN-002]-An Invoice shall have an Invoice number (BT-1).</assert>
         <assert test="(cbc:IssueDate) !=''" flag="fatal" id="PL-AN-003">[PL-AN-003]-An Invoice shall have an Invoice issue date (BT-2).</assert>
         <assert test="(cbc:DocumentCurrencyCode) !=''" flag="fatal" id="PL-AN-004">[PL-AN-004]-An Invoice shall have an Invoice currency code (BT-5).</assert>
         <assert test="(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cbc:RegistrationName) !=''"
                 flag="fatal"
                 id="PL-AN-005">[PL-AN-005]-An Invoice shall contain the Seller name (BT-27).</assert>
         <assert test="(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cbc:RegistrationName) !=''"
                 flag="fatal"
                 id="PL-AN-006">[PL-AN-006]-An Invoice shall contain the Buyer name (BT-44).</assert>
         <assert test="exists(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress)"
                 flag="fatal"
                 id="PL-AN-007">[PL-AN-007]-An Invoice shall contain the Seller postal address. </assert>
         <assert test="exists(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress)"
                 flag="fatal"
                 id="PL-AN-009">[PL-AN-009]-An Invoice shall contain the Buyer postal address (BG-8).</assert>
         <assert test="exists(cac:InvoiceLine) or exists(cac:CreditNoteLine)"
                 flag="fatal"
                 id="BR-16">[BR-16]-An Invoice shall have at least one Invoice line (BG-25)</assert>
      </rule>
      <rule context="cac:InvoiceLine | cac:CreditNoteLine">
         <assert test="(cbc:ID) != ''" flag="fatal" id="PL-AN-013">[PL-AN-013]-Each Invoice line (BG-25) shall have an Invoice line identifier (BT-126).</assert>
         <assert test="exists(cbc:LineExtensionAmount)" flag="fatal" id="PL-AN-014">[PL-AN-014]-Each Invoice line (BG-25) shall have an Invoice line net amount (BT-131).</assert>
         <assert test="string-length(substring-after(cbc:LineExtensionAmount,'.'))&lt;=2"
                 flag="fatal"
                 id="PL-AN-028">[PL-AN-028]-The allowed maximum number of decimals for the Invoice line net amount (BT-131) is 2.    </assert>
      </rule>
      <rule context="//ubl:Invoice/cbc:Note | //cn:CreditNote/cac:Note">
         <assert test="(contains(.,'#') and ( ( contains(' AAA AAB AAC AAD AAE AAF AAG AAI AAJ AAK AAL AAM AAN AAO AAP AAQ AAR AAS AAT AAU AAV AAW AAX AAY AAZ ABA ABB ABC ABD ABE ABF ABG ABH ABI ABJ ABK ABL ABM ABN ABO ABP ABQ ABR ABS ABT ABU ABV ABW ABX ABZ ACA ACB ACC ACD ACE ACF ACG ACH ACI ACJ ACK ACL ACM ACN ACO ACP ACQ ACR ACS ACT ACU ACV ACW ACX ACY ACZ ADA ADB ADC ADD ADE ADF ADG ADH ADI ADJ ADK ADL ADM ADN ADO ADP ADQ ADR ADS ADT ADU ADV ADW ADX ADY ADZ AEA AEB AEC AED AEE AEF AEG AEH AEI AEJ AEK AEL AEM AEN AEO AEP AEQ AER AES AET AEU AEV AEW AEX AEY AEZ AFA AFB AFC AFD AFE AFF AFG AFH AFI AFJ AFK AFL AFM AFN AFO AFP AFQ AFR AFS AFT AFU AFV AFW AFX AFY AFZ AGA AGB AGC AGD AGE AGF AGG AGH AGI AGJ AGK AGL AGM AGN AGO AGP AGQ AGR AGS AGT AGU AGV AGW AGX AGY AGZ AHA AHB AHC AHD AHE AHF AHG AHH AHI AHJ AHK AHL AHM AHN AHO AHP AHQ AHR AHS AHT AHU AHV AHW AHX AHY AHZ AIA AIB AIC AID AIE AIF AIG AIH AII AIJ AIK AIL AIM AIN AIO AIP AIQ AIR AIS AIT AIU AIV AIW AIX AIY AIZ AJA AJB ALC ALD ALE ALF ALG ALH ALI ALJ ALK ALL ALM ALN ALO ALP ALQ ARR ARS AUT AUU AUV AUW AUX AUY AUZ AVA AVB AVC AVD AVE AVF BAG BAH BAI BAJ BAK BAL BAM BAN BAO BAP BAQ BAR BAS BLC BLD BLE BLF BLG BLH BLI BLJ BLK BLL BLM BLN BLO BLP BLQ BLR BLS BLT BLU BLV BLW BLX BLY BLZ BMA BMB BMC BMD BME CCI CEX CHG CIP CLP CLR COI CUR CUS DAR DCL DEL DIN DOC DUT EUR FBC GBL GEN GS7 HAN HAZ ICN IIN IMI IND INS INV IRP ITR ITS LAN LIN LOI MCO MDH MKS ORI OSI PAC PAI PAY PKG PKT PMD PMT PRD PRF PRI PUR QIN QQD QUT RAH REG RET REV RQR SAF SIC SIN SLR SPA SPG SPH SPP SPT SRN SSR SUR TCA TDT TRA TRR TXD WHI ZZZ ',substring-before(substring-after(.,'#'),'#') ) ) )) or not(contains(.,'#'))"
                 flag="fatal"
                 id="PL-AN-019">[PL-AN-019]-Invoiced note subject code SHOULD be coded using UNCL4451</assert>
      </rule>
      <rule context="cac:AccountingSupplierParty">
         <assert test="exists(cac:Party/cac:PartyTaxScheme/cbc:CompanyID) or exists(cac:Party/cac:PartyIdentification/cbc:ID) or exists(cac:Party/cac:PartyLegalEntity/cbc:CompanyID)"
                 flag="fatal"
                 id="PL-AN-025">[PL-AN-025]-In order for the buyer to automatically identify a supplier, the Seller identifier (BT-29), the Seller legal registration identifier (BT-30) and/or the Seller VAT identifier (BT-31) shall be present.  </assert>
      </rule>
      <rule context="cac:AccountingSupplierParty/cac:Party/cbc:EndpointID">
         <assert test="exists(@schemeID)" flag="fatal" id="PL-AN-015">[PL-AN-015]-The Seller electronic address (BT-34) shall have a Scheme identifier.</assert>
      </rule>
      <rule context="cac:AccountingSupplierParty/cac:Party/cac:PostalAddress">
         <assert test="(cac:Country/cbc:IdentificationCode) != ''"
                 flag="fatal"
                 id="PL-AN-008">[PL-AN-008]-The Seller postal address (BG-5) shall contain a Seller country code (BT-40).</assert>
      </rule>
      <rule context="//cac:PartyTaxScheme[cac:TaxScheme/cbc:ID='VAT']">
         <assert test="( contains( ' 1A AD AE AF AG AI AL AM AO AQ AR AS AT AU AW AX AZ BA BB BD BE BF BG BH BI BJ BL BM BN BO BQ BR BS BT BV BW BY BZ CA CC CD CF CG CH CI CK CL CM CN CO CR CU CV CW CX CY CZ DE DJ DK DM DO DZ EC EE EG EH EL ER ES ET FI FJ FK FM FO FR GA GB GD GE GF GG GH GI GL GM GN GP GQ GR GS GT GU GW GY HK HM HN HR HT HU ID IE IL IM IN IO IQ IR IS IT JE JM JO JP KE KG KH KI KM KN KP KR KW KY KZ LA LB LC LI LK LR LS LT LU LV LY MA MC MD ME MF MG MH MK ML MM MN MO MP MQ MR MS MT MU MV MW MX MY MZ NA NC NE NF NG NI NL NO NP NR NU NZ OM PA PE PF PG PH PK PL PM PN PR PS PT PW PY QA RE RO RS RU RW SA SB SC SD SE SG SH SI SJ SK SL SM SN SO SR SS ST SV SX SY SZ TC TD TF TG TH TJ TK TL TM TN TO TR TT TV TW TZ UA UG UM US UY UZ VA VC VE VG VI VN VU WF WS XI YE YT ZA ZM ZW ',substring(cbc:CompanyID,1,2) ) )"
                 flag="fatal"
                 id="PL-AN-023">[PL-AN-023]-The Seller VAT identifier (BT-31), the Seller tax representative VAT identifier (BT-63) and the Buyer VAT identifier (BT-48) shall have a prefix in accordance with ISO code ISO 3166-1 alpha-2 by which the country of issue may be identified. Nevertheless, Greece may use the prefix ‘EL’.</assert>
      </rule>
   </pattern>
   
  <!--Start pattern based on abstract syntax--><pattern id="UBL-syntax">
      <rule context="//*[ends-with(name(), 'Amount') and not(ends-with(name(),'PriceAmount')) and not(ancestor::cac:Price/cac:AllowanceCharge)]">
         <assert test="string-length(substring-after(.,'.'))&lt;=2"
                 flag="fatal"
                 id="PL-AN-029">[PL-AN-029]-Amounts shall be decimal up to two fraction digits</assert>
      </rule>
   </pattern>
  
  <pattern id="Codesmodel">
  
      <rule context="cbc:Amount | cbc:LineExtensionAmount | cbc:PayableAmount"
            flag="fatal">
         <assert test="((not(contains(normalize-space(@currencyID), ' ')) and contains(' AED AFN ALL AMD ANG AOA ARS AUD AWG AZN BAM BBD BDT BGN BHD BIF BMD BND BOB BOV BRL BSD BTN BWP BYN BZD CAD CDF CHE CHF CHW CLF CLP CNY COP COU CRC CUC CUP CVE CZK DJF DKK DOP DZD EGP ERN ETB EUR FJD FKP GBP GEL GHS GIP GMD GNF GTQ GYD HKD HNL HTG HUF IDR ILS INR IQD IRR ISK JMD JOD JPY KES KGS KHR KMF KPW KRW KWD KYD KZT LAK LBP LKR LRD LSL LYD MAD MDL MGA MKD MMK MNT MOP MRO MUR MVR MWK MXN MXV MYR MZN NAD NGN NIO NOK NPR NZD OMR PAB PEN PGK PHP PKR PLN PYG QAR RON RSD RUB RWF SAR SBD SCR SDG SEK SGD SHP SLE SOS SRD SSP STD SVC SYP SZL THB TJS TMT TND TOP TRY TTD TWD TZS UAH UGX USD USN UYI UYU UZS VES VED VND VUV WST XAF XAG XAU XBA XBB XBC XBD XCD XDR XOF XPD XPF XPT XSU XTS XUA XXX YER ZAR ZMW ZWG ZWL ', concat(' ', normalize-space(@currencyID), ' '))))"
                 id="PL-AN-017"
                 flag="fatal">[PL-AN-017]-currencyID MUST be coded using ISO code list 4217 alpha-3</assert>
      </rule>
  
      <rule context="cbc:DocumentCurrencyCode" flag="fatal">
         <assert test="((not(contains(normalize-space(.), ' ')) and contains(' AED AFN ALL AMD ANG AOA ARS AUD AWG AZN BAM BBD BDT BGN BHD BIF BMD BND BOB BOV BRL BSD BTN BWP BYN BZD CAD CDF CHE CHF CHW CLF CLP CNY COP COU CRC CUC CUP CVE CZK DJF DKK DOP DZD EGP ERN ETB EUR FJD FKP GBP GEL GHS GIP GMD GNF GTQ GYD HKD HNL HTG HUF IDR ILS INR IQD IRR ISK JMD JOD JPY KES KGS KHR KMF KPW KRW KWD KYD KZT LAK LBP LKR LRD LSL LYD MAD MDL MGA MKD MMK MNT MOP MRO MUR MVR MWK MXN MXV MYR MZN NAD NGN NIO NOK NPR NZD OMR PAB PEN PGK PHP PKR PLN PYG QAR RON RSD RUB RWF SAR SBD SCR SDG SEK SGD SHP SLE SOS SRD SSP STD SVC SYP SZL THB TJS TMT TND TOP TRY TTD TWD TZS UAH UGX USD USN UYI UYU UZS VES VED VND VUV WST XAF XAG XAU XBA XBB XBC XBD XCD XDR XOF XPD XPF XPT XSU XTS XUA XXX YER ZAR ZMW ZWG ZWL ', concat(' ', normalize-space(.), ' '))))"
                 id="PL-AN-018"
                 flag="fatal">[PL-AN-018]-Invoice currency code MUST be coded using ISO code list 4217 alpha-3</assert>
      </rule>

<!-- 2018-11-13 - Added newest ICD values manually -->
      <rule context="cac:PartyIdentification/cbc:ID[@schemeID]" flag="fatal">
         <assert test="((not(contains(normalize-space(@schemeID), ' ')) and contains(' 0002 0003 0004 0005 0006 0007 0008 0009 0010 0011 0012 0013 0014 0015 0016 0017 0018 0019 0020 0021 0022 0023 0024 0025 0026 0027 0028 0029 0030 0031 0032 0033 0034 0035 0036 0037 0038 0039 0040 0041 0042 0043 0044 0045 0046 0047 0048 0049 0050 0051 0052 0053 0054 0055 0056 0057 0058 0059 0060 0061 0062 0063 0064 0065 0066 0067 0068 0069 0070 0071 0072 0073 0074 0075 0076 0077 0078 0079 0080 0081 0082 0083 0084 0085 0086 0087 0088 0089 0090 0091 0093 0094 0095 0096 0097 0098 0099 0100 0101 0102 0104 0105 0106 0107 0108 0109 0110 0111 0112 0113 0114 0115 0116 0117 0118 0119 0120 0121 0122 0123 0124 0125 0126 0127 0128 0129 0130 0131 0132 0133 0134 0135 0136 0137 0138 0139 0140 0141 0142 0143 0144 0145 0146 0147 0148 0149 0150 0151 0152 0153 0154 0155 0156 0157 0158 0159 0160 0161 0162 0163 0164 0165 0166 0167 0168 0169 0170 0171 0172 0173 0174 0175 0176 0177 0178 0179 0180 0183 0184 0185 0186 0187 0188 0189 0190 0191 0192 0193 0194 0195 0196 0197 0198 0199 0200 0201 0202 0203 0204 0205 0206 0207 0208 0209 0210 0211 0212 0213 0214 0215 0216 0217 0218 0219 0220 0221 0222 0223 0224 0225 0226 0227 0228 0229 0230 ', concat(' ', normalize-space(@schemeID), ' '))))  or ((not(contains(normalize-space(@schemeID), ' ')) and contains(' SEPA ', concat(' ', normalize-space(@schemeID), ' '))) and ((ancestor::cac:AccountingSupplierParty) or (ancestor::cac:PayeeParty)))"
                 id="PL-AN-020"
                 flag="fatal">[PL-AN-020]-Any identifier identification scheme identifier MUST be coded using one of the ISO 6523 ICD list.</assert>
      </rule>
          <!-- 2018-11-13 - Added newest ICD values manually -->
      <rule context="cac:PartyLegalEntity/cbc:CompanyID[@schemeID]" flag="fatal">
              <assert test="((not(contains(normalize-space(@schemeID), ' ')) and contains(' 0002 0003 0004 0005 0006 0007 0008 0009 0010 0011 0012 0013 0014 0015 0016 0017 0018 0019 0020 0021 0022 0023 0024 0025 0026 0027 0028 0029 0030 0031 0032 0033 0034 0035 0036 0037 0038 0039 0040 0041 0042 0043 0044 0045 0046 0047 0048 0049 0050 0051 0052 0053 0054 0055 0056 0057 0058 0059 0060 0061 0062 0063 0064 0065 0066 0067 0068 0069 0070 0071 0072 0073 0074 0075 0076 0077 0078 0079 0080 0081 0082 0083 0084 0085 0086 0087 0088 0089 0090 0091 0093 0094 0095 0096 0097 0098 0099 0100 0101 0102 0104 0105 0106 0107 0108 0109 0110 0111 0112 0113 0114 0115 0116 0117 0118 0119 0120 0121 0122 0123 0124 0125 0126 0127 0128 0129 0130 0131 0132 0133 0134 0135 0136 0137 0138 0139 0140 0141 0142 0143 0144 0145 0146 0147 0148 0149 0150 0151 0152 0153 0154 0155 0156 0157 0158 0159 0160 0161 0162 0163 0164 0165 0166 0167 0168 0169 0170 0171 0172 0173 0174 0175 0176 0177 0178 0179 0180 0183 0184 0185 0186 0187 0188 0189 0190 0191 0192 0193 0194 0195 0196 0197 0198 0199 0200 0201 0202 0203 0204 0205 0206 0207 0208 0209 0210 0211 0212 0213 0214 0215 0216 0217 0218 0219 0220 0221 0222 0223 0224 0225 0226 0227 0228 0229 0230 0231 0232 0233 0234 0235 0236 0237 0238 ', concat(' ', normalize-space(@schemeID), ' '))))"
                 id="PL-AN-021"
                 flag="fatal">[PL-AN-021]-Any registration identifier identification scheme identifier MUST be coded using one of the ISO 6523 ICD list.</assert>
      </rule>
  
      <rule context="cac:Country/cbc:IdentificationCode" flag="fatal">
         <assert test="((not(contains(normalize-space(.), ' ')) and contains(' 1A AD AE AF AG AI AL AM AO AQ AR AS AT AU AW AX AZ BA BB BD BE BF BG BH BI BJ BL BM BN BO BQ BR BS BT BV BW BY BZ CA CC CD CF CG CH CI CK CL CM CN CO CR CU CV CW CX CY CZ DE DJ DK DM DO DZ EC EE EG EH ER ES ET FI FJ FK FM FO FR GA GB GD GE GF GG GH GI GL GM GN GP GQ GR GS GT GU GW GY HK HM HN HR HT HU ID IE IL IM IN IO IQ IR IS IT JE JM JO JP KE KG KH KI KM KN KP KR KW KY KZ LA LB LC LI LK LR LS LT LU LV LY MA MC MD ME MF MG MH MK ML MM MN MO MP MQ MR MS MT MU MV MW MX MY MZ NA NC NE NF NG NI NL NO NP NR NU NZ OM PA PE PF PG PH PK PL PM PN PR PS PT PW PY QA RE RO RS RU RW SA SB SC SD SE SG SH SI SJ SK SL SM SN SO SR SS ST SV SX SY SZ TC TD TF TG TH TJ TK TL TM TN TO TR TT TV TW TZ UA UG UM US UY UZ VA VC VE VG VI VN VU WF WS XI YE YT ZA ZM ZW ', concat(' ', normalize-space(.), ' '))))"
                 id="PL-AN-022"
                 flag="fatal">[PL-AN-022]-Country codes in an invoice MUST be coded using ISO code list 3166-1</assert>
      </rule>
  
   </pattern>

  <!-- Empty elements -->
  <pattern>
    <rule context="cbc:*">
      <assert id="PL-AN-037" test=". != ''" flag="fatal">Document MUST not contain empty
        elements.</assert>
    </rule>
    <rule context="cac:*">
      <assert id="PL-AN-038" test="count(*) != 0" flag="fatal">Document MUST not contain
        empty elements.</assert>
    </rule>
  </pattern>

  <pattern>

    <!-- Document level -->
    <rule context="//cn:CreditNote | //ubl:Invoice">
      <assert id="PL-AN-034" test="cbc:ProfileID" flag="fatal">Business process MUST be
        provided.</assert>
      <assert id="PL-AN-034-1"
        test="starts-with(normalize-space(cbc:ProfileID/text()), 'urn:fdc:www.efaktura.gov.pl:ver1.0:account_corr:ver1.0')"
        flag="fatal">Profile identifier MUST have the value 'urn:fdc:www.efaktura.gov.pl:ver1.0:account_corr:ver1.0'</assert>
      <assert id="PL-AN-035" test="count(cbc:Note) &lt;= 1" flag="fatal">No more than one
        note is allowed on document level.</assert>
      <assert id="PL-AN-001-1"
        test="starts-with(normalize-space(cbc:CustomizationID/text()), 'urn:fdc:www.efaktura.gov.pl:ver1.0:trns:account_corr:ver1.0')"
        flag="fatal">Specification identifier MUST have the value 'urn:fdc:www.efaktura.gov.pl:ver1.0:trns:account_corr:ver1.0'</assert>
    </rule>

    <!-- Accounting customer -->
    <rule context="cac:AccountingCustomerParty/cac:Party">
      <assert id="PL-AN-039" test="cbc:EndpointID" flag="fatal">Buyer electronic address
        MUST be provided</assert>
    </rule>

    <!-- Accounting supplier -->
    <rule context="cac:AccountingSupplierParty/cac:Party">
      <assert id="PL-AN-040" test="cbc:EndpointID" flag="fatal">Seller electronic address
        MUST be provided</assert>
    </rule>
      
    <!-- GLN validity -->    
     <rule context="cbc:EndpointID[@schemeID = '0088'] | cbc:ID[@schemeID = '0088'] | cbc:CompanyID[@schemeID = '0088']">
      <assert id="PL-AN-042"
                 test="matches(normalize-space(), '^[0-9]+$') and u:gln(normalize-space())"
                 flag="fatal">GLN must have a valid format according to GS1 rules.</assert>
    </rule> 
    
    
    
    <!-- Total level  -->
    <rule context="cac:LegalMonetaryTotal">
	<!-- Line extension amount -->
      <assert id="PL-AN-047" test="cbc:LineExtensionAmount" flag="fatal">Line extension amount on total level 
        MUST be provided</assert>
	<!-- Payable amount  -->
      <assert id="PL-AN-048" test="cbc:PayableAmount" flag="fatal">Payable amount on total level  
        MUST be provided</assert>
	<!-- Line extencion amount & Payable amount -->
      <assert id="PL-AN-049" test="cbc:LineExtensionAmount = cbc:PayableAmount" flag="fatal">Line extension amount and payable amount (on total level) 
        MUST have the same value</assert>
    </rule>

    <!-- Currency -->
    <rule
      context="cbc:LineExtensionAmount">
      <assert id="PL-AN-041" test="@currencyID = $documentCurrencyCode" flag="fatal">All
        currencyID attributes must have the same value as the invoice currency code (BT-5), except
        for the invoice total VAT amount in accounting currency (BT-111) </assert>
    </rule>

    <!-- Line level - line extension amount -->
    <rule context="cac:CreditNoteLine">
      <let name="lineExtensionAmount"
        value="
          if (cbc:LineExtensionAmount) then
            xs:decimal(cbc:LineExtensionAmount)
          else
            0"/>
    </rule>

    <!-- Line level  -->
    <rule context="cac:CreditNoteLine">
	<!-- Line identifier -->
      <assert id="PL-AN-044" test="cbc:ID" flag="fatal">Line ID 
        MUST be provided</assert>
	<!-- Note  -->
      <assert id="PL-AN-045" test="cbc:Note" flag="fatal">Note on line level  
        MUST be provided</assert>
	<!-- Line extencion amount -->
      <assert id="PL-AN-046" test="cbc:LineExtensionAmount" flag="fatal">Line extension amount on line level 
        MUST be provided</assert>
    </rule>

  </pattern>

  <!-- Restricted code lists and formatting -->
  <pattern>
    <let name="ISO3166"
      value="tokenize(' AD AE AF AG AI AL AM AO AQ AR AS AT AU AW AX AZ BA BB BD BE BF BG BH BI BJ BL BM BN BO BQ BR BS BT BV BW BY BZ CA CC CD CF CG CH CI CK CL CM CN CO CR CU CV CW CX CY CZ DE DJ DK DM DO DZ EC EE EG EH ER ES ET FI FJ FK FM FO FR GA GB GD GE GF GG GH GI GL GM GN GP GQ GR GS GT GU GW GY HK HM HN HR HT HU ID IE IL IM IN IO IQ IR IS IT JE JM JO JP KE KG KH KI KM KN KP KR KW KY KZ LA LB LC LI LK LR LS LT LU LV LY MA MC MD ME MF MG MH MK ML MM MN MO MP MQ MR MS MT MU MV MW MX MY MZ NA NC NE NF NG NI NL NO NP NR NU NZ OM PA PE PF PG PH PK PL PM PN PR PS PT PW PY QA RE RO RS RU RW SA SB SC SD SE SG SH SI SJ SK SL SM SN SO SR SS ST SV SX SY SZ TC TD TF TG TH TJ TK TL TM TN TO TR TT TV TW TZ UA UG UM US UY UZ VA VC VE VG VI VN VU WF WS YE YT ZA ZM ZW 1A XI ', '\s')"/>
    <let name="ISO4217"
      value="tokenize(' AED AFN ALL AMD ANG AOA ARS AUD AWG AZN BAM BBD BDT BGN BHD BIF BMD BND BOB BOV BRL BSD BTN BWP BYN BZD CAD CDF CHE CHF CHW CLF CLP CNY COP COU CRC CUC CUP CVE CZK DJF DKK DOP DZD EGP ERN ETB EUR FJD FKP GBP GEL GHS GIP GMD GNF GTQ GYD HKD HNL HTG HUF IDR ILS INR IQD IRR ISK JMD JOD JPY KES KGS KHR KMF KPW KRW KWD KYD KZT LAK LBP LKR LRD LSL LYD MAD MDL MGA MKD MMK MNT MOP MRO MUR MVR MWK MXN MXV MYR MZN NAD NGN NIO NOK NPR NZD OMR PAB PEN PGK PHP PKR PLN PYG QAR RON RSD RUB RWF SAR SBD SCR SDG SEK SGD SHP SLE SOS SRD SSP STD SVC SYP SZL THB TJS TMT TND TOP TRY TTD TWD TZS UAH UGX USD USN UYI UYU UZS VES VED VND VUV WST XAF XAG XAU XBA XBB XBC XBD XCD XDR XOF XPD XPF XPT XSU XTS XUA XXX YER ZAR ZMW ZWG ZWL ', '\s')"/>
    <let name="MIMECODE"
      value="tokenize('application/pdf image/png image/jpeg text/csv application/vnd.openxmlformats-officedocument.spreadsheetml.sheet application/vnd.oasis.opendocument.spreadsheet', '\s')"/>
    <let name="UNCL2005" value="tokenize('3 35 432', '\s')"/>
    <let name="UNCL5189"
      value="tokenize('41 42 60 62 63 64 65 66 67 68 70 71 88 95 100 102 103 104 105', '\s')"/>
    <let name="UNCL7161"
      value="tokenize(' AA AAA AAC AAD AAE AAF AAH AAI AAS AAT AAV AAY AAZ ABA ABB ABC ABD ABF ABK ABL ABN ABR ABS ABT ABU ACF ACG ACH ACI ACJ ACK ACL ACM ACS ADC ADE ADJ ADK ADL ADM ADN ADO ADP ADQ ADR ADT ADW ADY ADZ AEA AEB AEC AED AEF AEH AEI AEJ AEK AEL AEM AEN AEO AEP AES AET AEU AEV AEW AEX AEY AEZ AJ AU CA CAB CAD CAE CAF CAI CAJ CAK CAL CAM CAN CAO CAP CAQ CAR CAS CAT CAU CAV CAW CAX CAY CAZ CD CG CS CT DAB DAD DAC DAF DAG DAH DAI DAJ DAK DAL DAM DAN DAO DAP DAQ DL EG EP ER FAA FAB FAC FC FH FI GAA HAA HD HH IAA IAB ID IF IR IS KO L1 LA LAA LAB LF MAE MI ML NAA OA PA PAA PC PL PRV RAB RAC RAD RAF RE RF RH RV SA SAA SAD SAE SAI SG SH SM SU TAB TAC TT TV V1 V2 WH XAA YY ZZZ ', '\s')"/>
    <let name="UNCL5305" value="tokenize('AE E S Z G O K L M B', '\s')"/>
    <let name="eaid" value="tokenize(' 0002 0007 0009 0037 0060 0088 0096 0097 0106 0130 0135 0142 0147 0151 0170 0177 0183 0184 0188 0190 0191 0192 0193 0195 0196 0198 0199 0200 0201 0202 0204 0208 0209 0210 0211 0212 0213 0215 0216 0218 0221 0230 0235 9901 9906 9907 9910 9913 9914 9915 9918 9919 9920 9922 9923 9924 9925 9926 9927 9928 9929 9930 9931 9932 9933 9934 9935 9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 9948 9949 9950 9951 9952 9953 9957 9959 ', '\s')"/>


    <rule context="cac:Country/cbc:IdentificationCode | cac:OriginCountry/cbc:IdentificationCode">
      <assert id="PL-AN-030"
        test="
          some $code in $ISO3166
            satisfies text() = $code" flag="fatal"
        >Country code MUST be according to ISO 3166 Alpha-2.</assert>
    </rule>

    <rule
      context="cbc:Amount | cbc:BaseAmount | cbc:PriceAmount | cbc:TaxAmount | cbc:TaxableAmount | cbc:LineExtensionAmount | cbc:TaxExclusiveAmount | cbc:TaxInclusiveAmount | cbc:AllowanceTotalAmount | cbc:ChargeTotalAmount | cbc:PrepaidAmount | cbc:PayableRoundingAmount | cbc:PayableAmount">
      <assert id="PL-AN-031"
        test="
          some $code in $ISO4217
            satisfies @currencyID = $code"
        flag="fatal">Currency code must be according to ISO 4217:2005</assert>
    </rule>

    <rule
      context="cbc:IssueDate | cbc:DueDate | cbc:TaxPointDate | cbc:StartDate | cbc:EndDate | cbc:ActualDeliveryDate">
      <assert id="PL-AN-033"
        test="string-length(text()) = 10 and (string(.) castable as xs:date)" flag="fatal">A date
        MUST be formatted YYYY-MM-DD.</assert>
    </rule>
    
    <rule context="cbc:EndpointID[@schemeID]">
      <assert id="PL-AN-032"
        test="
        some $code in $eaid
        satisfies @schemeID = $code"
        flag="fatal">Electronic address identifier scheme must be from the codelist "Electronic Address Identifier Scheme"</assert>
    </rule>
  </pattern>
  
  <!--Start pattern based on abstract syntax-->
  <pattern id="UBL-syntax-Ex">
      <rule context="//*[ends-with(name(), 'Amount') and not(ends-with(name(),'PriceAmount')) and not(ancestor::cac:Price/cac:AllowanceCharge)]">
         <assert test="string-length(substring-after(.,'.'))&lt;=2"
                 flag="fatal"
                 id="UBL-DT-01">[UBL-DT-01]-Amounts shall be decimal up to two fraction digits</assert>
      </rule>

      <rule context="cac:AllowanceCharge[cbc:ChargeIndicator = 'false']">
         <assert test="(count(cbc:AllowanceChargeReason) &lt;= 1)"
                 flag="warning"
                 id="UBL-SR-30">[UBL-SR-30]-Document level allowance reason shall occur maximum once</assert>
      </rule>
      <rule context="cac:AllowanceCharge[cbc:ChargeIndicator = 'true']">
         <assert test="(count(cbc:AllowanceChargeReason) &lt;= 1)"
                 flag="warning"
                 id="UBL-SR-31">[UBL-SR-31]-Document level charge reason shall occur maximum once</assert>
      </rule>
      <rule context="//cn:CreditNote">
         <assert test="not(cbc:ProfileExecutionID)" flag="warning" id="UBL-AN-003">[UBL-AN-003]-A UBL accounting note should not include the ProfileExecutionID </assert>
         <assert test="not(cbc:CopyIndicator)" flag="warning" id="UBL-AN-004">[UBL-AN-004]-A UBL accounting note should not include the CopyIndicator </assert>
         <assert test="not(cbc:UUID)" flag="warning" id="UBL-AN-005">[UBL-AN-005]-A UBL accounting note should not include the UUID </assert>
         <assert test="not(cbc:IssueTime)" flag="warning" id="UBL-AN-006">[UBL-AN-006]-A UBL accounting note should not include the IssueTime </assert>
         <assert test="not(cbc:PricingCurrencyCode)" flag="warning" id="UBL-AN-007">[UBL-AN-007]-A UBL accounting note should not include the PricingCurrencyCode</assert>
         <assert test="not(cbc:PaymentCurrencyCode)" flag="warning" id="UBL-AN-008">[UBL-AN-008]-A UBL accounting note should not include the PaymentCurrencyCode</assert>
         <assert test="not(cbc:PaymentAlternativeCurrencyCode)"
                 flag="warning"
                 id="UBL-AN-009">[UBL-AN-009]-A UBL accounting note should not include the PaymentAlternativeCurrencyCode</assert>
         <assert test="not(cbc:AccountingCostCode)" flag="warning" id="UBL-AN-010">[UBL-AN-010]-A UBL accounting note should not include the AccountingCostCode</assert>
         <assert test="not(cbc:LineCountNumeric)" flag="warning" id="UBL-AN-011">[UBL-AN-011]-A UBL accounting note should not include the LineCountNumeric</assert>
         <assert test="not(cac:InvoicePeriod)"
                 flag="warning"
                 id="UBL-AN-012">[UBL-AN-012]-A UBL accounting note should not include the InvoicePeriod</assert>
          <assert test="not(cac:OrderReference)"
                 flag="warning"
                 id="UBL-AN-016">[UBL-AN-016]-A UBL accounting note should not include the OrderReference</assert>
          <assert test="not(cac:BillingReference)"
                 flag="warning"
                 id="UBL-AN-023">[UBL-AN-023]-A UBL accounting note should not include the BillingReference</assert>
         <assert test="not(cac:DespatchDocumentReference)"
                 flag="warning"
                 id="UBL-AN-045">[UBL-AN-045]-A UBL accounting note should not include the DespatchDocumentReference</assert>
         <assert test="not(cac:ReceiptDocumentReference)"
                 flag="warning"
                 id="UBL-AN-061">[UBL-AN-061]-A UBL accounting note should not include the ReceiptDocumentReference</assert>
         <assert test="not(cac:StatementDocumentReference)"
                 flag="warning"
                 id="UBL-AN-077">[UBL-AN-077]-A UBL accounting note should not include the StatementDocumentReference</assert>
         <assert test="not(cac:OriginatorDocumentReference)"
                 flag="warning"
                 id="UBL-AN-078">[UBL-AN-078]-A UBL accounting note should not include the OriginatorDocumentReference</assert>
         <assert test="not(cac:ContractDocumentReference/cbc:CopyIndicator)"
                 flag="warning"
                 id="UBL-AN-094">[UBL-AN-094]-A UBL accounting note should not include the ContractDocumentReference CopyIndicator</assert>
         <assert test="not(cac:ContractDocumentReference/cbc:UUID)"
                 flag="warning"
                 id="UBL-AN-095">[UBL-AN-095]-A UBL accounting note should not include the ContractDocumentReference UUID</assert>
         <assert test="not(cac:ContractDocumentReference/cbc:IssueDate)"
                 flag="warning"
                 id="UBL-AN-096">[UBL-AN-096]-A UBL accounting note should not include the ContractDocumentReference IssueDate</assert>
         <assert test="not(cac:ContractDocumentReference/cbc:IssueTime)"
                 flag="warning"
                 id="UBL-AN-097">[UBL-AN-097]-A UBL accounting note should not include the ContractDocumentReference IssueTime</assert>
         <assert test="not(cac:ContractDocumentReference/cbc:DocumentTypeCode)"
                 flag="warning"
                 id="UBL-AN-098">[UBL-AN-098]-A UBL accounting note should not include the ContractDocumentReference DocumentTypeCode</assert>
         <assert test="not(cac:ContractDocumentReference/cbc:DocumentType)"
                 flag="warning"
                 id="UBL-AN-099">[UBL-AN-099]-A UBL accounting note should not include the ContractDocumentReference DocumentType</assert>
         <assert test="not(cac:ContractDocumentReference/cbc:Xpath)"
                 flag="warning"
                 id="UBL-AN-100">[UBL-AN-100]-A UBL accounting note should not include the ContractDocumentReference Xpath</assert>
         <assert test="not(cac:ContractDocumentReference/cbc:LanguageID)"
                 flag="warning"
                 id="UBL-AN-101">[UBL-AN-101]-A UBL accounting note should not include the ContractDocumentReference LanguageID</assert>
         <assert test="not(cac:ContractDocumentReference/cbc:LocaleCode)"
                 flag="warning"
                 id="UBL-AN-102">[UBL-AN-102]-A UBL accounting note should not include the ContractDocumentReference LocaleCode</assert>
         <assert test="not(cac:ContractDocumentReference/cbc:VersionID)"
                 flag="warning"
                 id="UBL-AN-103">[UBL-AN-103]-A UBL accounting note should not include the ContractDocumentReference VersionID</assert>
         <assert test="not(cac:ContractDocumentReference/cbc:DocumentStatusCode)"
                 flag="warning"
                 id="UBL-AN-104">[UBL-AN-104]-A UBL accounting note should not include the ContractDocumentReference DocumentStatusCode</assert>
         <assert test="not(cac:ContractDocumentReference/cbc:DocumentDescription)"
                 flag="warning"
                 id="UBL-AN-105">[UBL-AN-105]-A UBL accounting note should not include the ContractDocumentReference DocumentDescription</assert>
         <assert test="not(cac:ContractDocumentReference/cac:Attachment)"
                 flag="warning"
                 id="UBL-AN-106">[UBL-AN-106]-A UBL accounting note should not include the ContractDocumentReference Attachment</assert>
         <assert test="not(cac:ContractDocumentReference/cac:ValidityPeriod)"
                 flag="warning"
                 id="UBL-AN-107">[UBL-AN-107]-A UBL accounting note should not include the ContractDocumentReference ValidityPeriod</assert>
         <assert test="not(cac:ContractDocumentReference/cac:IssuerParty)"
                 flag="warning"
                 id="UBL-AN-108">[UBL-AN-108]-A UBL accounting note should not include the ContractDocumentReference IssuerParty</assert>
         <assert test="not(cac:ContractDocumentReference/cac:ResultOfVerification)"
                 flag="warning"
                 id="UBL-AN-109">[UBL-AN-109]-A UBL accounting note should not include the ContractDocumentReference ResultOfVerification</assert>
         <assert test="not(cac:AdditionalDocumentReference)"
                 flag="warning"
                 id="UBL-AN-110">[UBL-AN-110]-A UBL accounting note should not include the AdditionalDocumentReference </assert>
         <assert test="not(cac:ProjectReference)"
                 flag="warning"
                 id="UBL-AN-134">[UBL-AN-134]-A UBL accounting note should not include the ProjectReference</assert>
         <assert test="not(cac:Signature)" flag="warning" id="UBL-AN-137">[UBL-AN-137]-A UBL accounting note should not include the Signature</assert>
         <assert test="not(cac:AccountingSupplierParty/cbc:CustomerAssignedAccountID)"
                 flag="warning"
                 id="UBL-AN-138">[UBL-AN-138]-A UBL accounting note should not include the AccountingSupplierParty CustomerAssignedAccountID</assert>
         <assert test="not(cac:AccountingSupplierParty/cbc:AdditionalAccountID)"
                 flag="warning"
                 id="UBL-AN-139">[UBL-AN-139]-A UBL accounting note should not include the AccountingSupplierParty AdditionalAccountID</assert>
         <assert test="not(cac:AccountingSupplierParty/cbc:DataSendingCapability)"
                 flag="warning"
                 id="UBL-AN-140">[UBL-AN-140]-A UBL accounting note should not include the AccountingSupplierParty DataSendingCapability</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cbc:MarkCareIndicator)"
                 flag="warning"
                 id="UBL-AN-141">[UBL-AN-141]-A UBL accounting note should not include the AccountingSupplierParty Party MarkCareIndicator</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cbc:MarkAttentionIndicator)"
                 flag="warning"
                 id="UBL-AN-142">[UBL-AN-142]-A UBL accounting note should not include the AccountingSupplierParty Party MarkAttentionIndicator</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cbc:WebsiteURI)"
                 flag="warning"
                 id="UBL-AN-143">[UBL-AN-143]-A UBL accounting note should not include the AccountingSupplierParty Party WebsiteURI</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cbc:LogoReferenceID)"
                 flag="warning"
                 id="UBL-AN-144">[UBL-AN-144]-A UBL accounting note should not include the AccountingSupplierParty Party LogoReferenceID</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cbc:IndustryClassificationCode)"
                 flag="warning"
                 id="UBL-AN-145">[UBL-AN-145]-A UBL accounting note should not include the AccountingSupplierParty Party IndustryClassificationCode</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:Language)"
                 flag="warning"
                 id="UBL-AN-146">[UBL-AN-146]-A UBL accounting note should not include the AccountingSupplierParty Party Language</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:ID)"
                 flag="warning"
                 id="UBL-AN-147">[UBL-AN-147]-A UBL accounting note should not include the AccountingSupplierParty Party PostalAddress ID</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:AddressTypeCode)"
                 flag="warning"
                 id="UBL-AN-148">[UBL-AN-148]-A UBL accounting note should not include the AccountingSupplierParty Party PostalAddress AddressTypeCode</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:AddressFormatCode)"
                 flag="warning"
                 id="UBL-AN-149">[UBL-AN-149]-A UBL accounting note should not include the AccountingSupplierParty Party PostalAddress AddressFormatCode</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:Postbox)"
                 flag="warning"
                 id="UBL-AN-150">[UBL-AN-150]-A UBL accounting note should not include the AccountingSupplierParty Party PostalAddress Postbox</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:Floor)"
                 flag="warning"
                 id="UBL-AN-151">[UBL-AN-151]-A UBL accounting note should not include the AccountingSupplierParty Party PostalAddress Floor</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:Room)"
                 flag="warning"
                 id="UBL-AN-152">[UBL-AN-152]-A UBL accounting note should not include the AccountingSupplierParty Party PostalAddress Room</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:BlockName)"
                 flag="warning"
                 id="UBL-AN-153">[UBL-AN-153]-A UBL accounting note should not include the AccountingSupplierParty Party PostalAddress BlockName</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:BuildingName)"
                 flag="warning"
                 id="UBL-AN-154">[UBL-AN-154]-A UBL accounting note should not include the AccountingSupplierParty Party PostalAddress BuildingName</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:BuildingNumber)"
                 flag="warning"
                 id="UBL-AN-155">[UBL-AN-155]-A UBL accounting note should not include the AccountingSupplierParty Party PostalAddress BuildingNumber</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:InhouseMail)"
                 flag="warning"
                 id="UBL-AN-156">[UBL-AN-156]-A UBL accounting note should not include the AccountingSupplierParty Party PostalAddress InhouseMail</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:Department)"
                 flag="warning"
                 id="UBL-AN-157">[UBL-AN-157]-A UBL accounting note should not include the AccountingSupplierParty Party PostalAddress Department</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:MarkAttention)"
                 flag="warning"
                 id="UBL-AN-158">[UBL-AN-158]-A UBL accounting note should not include the AccountingSupplierParty Party PostalAddress MarkAttention</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:MarkCare)"
                 flag="warning"
                 id="UBL-AN-159">[UBL-AN-159]-A UBL accounting note should not include the AccountingSupplierParty Party PostalAddress MarkCare</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:PlotIdentification)"
                 flag="warning"
                 id="UBL-AN-160">[UBL-AN-160]-A UBL accounting note should not include the AccountingSupplierParty Party PostalAddress PlotIdentification</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:CitySubdivisionName)"
                 flag="warning"
                 id="UBL-AN-161">[UBL-AN-161]-A UBL accounting note should not include the AccountingSupplierParty Party PostalAddress CitySubdivisionName</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:CountrySubentityCode)"
                 flag="warning"
                 id="UBL-AN-162">[UBL-AN-162]-A UBL accounting note should not include the AccountingSupplierParty Party PostalAddress CountrySubentityCode</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:Region)"
                 flag="warning"
                 id="UBL-AN-163">[UBL-AN-163]-A UBL accounting note should not include the AccountingSupplierParty Party PostalAddress Region</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:District)"
                 flag="warning"
                 id="UBL-AN-164">[UBL-AN-164]-A UBL accounting note should not include the AccountingSupplierParty Party PostalAddress District</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:TimezoneOffset)"
                 flag="warning"
                 id="UBL-AN-165">[UBL-AN-165]-A UBL accounting note should not include the AccountingSupplierParty Party PostalAddress TimezoneOffset</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cac:Country/cbc:Name)"
                 flag="warning"
                 id="UBL-AN-166">[UBL-AN-166]-A UBL accounting note should not include the AccountingSupplierParty Party PostalAddress Country Name</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cac:LocationCoordinate)"
                 flag="warning"
                 id="UBL-AN-167">[UBL-AN-167]-A UBL accounting note should not include the AccountingSupplierParty Party PostalAddress LocationCoordinate</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PhysicalLocation)"
                 flag="warning"
                 id="UBL-AN-168">[UBL-AN-168]-A UBL accounting note should not include the AccountingSupplierParty Party PhysicalLocation</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cbc:RegistrationName)"
                 flag="warning"
                 id="UBL-AN-169">[UBL-AN-169]-A UBL accounting note should not include the AccountingSupplierParty Party PartyTaxScheme RegistrationName</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cbc:TaxLevelCode)"
                 flag="warning"
                 id="UBL-AN-170">[UBL-AN-170]-A UBL accounting note should not include the AccountingSupplierParty Party PartyTaxScheme TaxLevelCode</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cbc:ExemptionReasonCode)"
                 flag="warning"
                 id="UBL-AN-171">[UBL-AN-171]-A UBL accounting note should not include the AccountingSupplierParty Party PartyTaxScheme ExemptionReasonCode</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cbc:ExemptionReason)"
                 flag="warning"
                 id="UBL-AN-172">[UBL-AN-172]-A UBL accounting note should not include the AccountingSupplierParty Party PartyTaxScheme ExemptionReason</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cac:RegistrationAddress)"
                 flag="warning"
                 id="UBL-AN-173">[UBL-AN-173]-A UBL accounting note should not include the AccountingSupplierParty Party PartyTaxScheme RegistrationAddress</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cac:TaxScheme/cbc:Name)"
                 flag="warning"
                 id="UBL-AN-174">[UBL-AN-174]-A UBL accounting note should not include the AccountingSupplierParty Party PartyTaxScheme TaxScheme Name</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cac:TaxScheme/cbc:TaxTypeCode)"
                 flag="warning"
                 id="UBL-AN-175">[UBL-AN-175]-A UBL accounting note should not include the AccountingSupplierParty Party PartyTaxScheme TaxScheme TaxTypeCode</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cac:TaxScheme/cbc:CurrencyCode)"
                 flag="warning"
                 id="UBL-AN-176">[UBL-AN-176]-A UBL accounting note should not include the AccountingSupplierParty Party PartyTaxScheme TaxScheme CurrencyCode</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cac:TaxScheme/cac:JurisdictionRegionAddress)"
                 flag="warning"
                 id="UBL-AN-177">[UBL-AN-177]-A UBL accounting note should not include the AccountingSupplierParty Party PartyTaxScheme TaxScheme JurisdictionRegionAddress</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cbc:RegistrationDate)"
                 flag="warning"
                 id="UBL-AN-178">[UBL-AN-178]-A UBL accounting note should not include the AccountingSupplierParty Party PartyLegalEntity RegistrationDate</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cbc:RegistrationExpirationDate)"
                 flag="warning"
                 id="UBL-AN-179">[UBL-AN-179]-A UBL accounting note should not include the AccountingSupplierParty Party PartyLegalEntity RegistrationExpirationDate</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cbc:CompanyLegalFormCode)"
                 flag="warning"
                 id="UBL-AN-180">[UBL-AN-180]-A UBL accounting note should not include the AccountingSupplierParty Party PartyLegalEntity CompanyLegalFormCode</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cbc:SoleProprietorshipIndicator)"
                 flag="warning"
                 id="UBL-AN-181">[UBL-AN-181]-A UBL accounting note should not include the AccountingSupplierParty Party PartyLegalEntity SoleProprietorshipIndicator</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cbc:CompanyLiquidationStatusCode)"
                 flag="warning"
                 id="UBL-AN-182">[UBL-AN-182]-A UBL accounting note should not include the AccountingSupplierParty Party PartyLegalEntity CompanyLiquidationStatusCode</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cbc:CorporationStockAmount)"
                 flag="warning"
                 id="UBL-AN-183">[UBL-AN-183]-A UBL accounting note should not include the AccountingSupplierParty Party PartyLegalEntity CorporationStockAmount</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cbc:FullyPaidSharesIndicator)"
                 flag="warning"
                 id="UBL-AN-184">[UBL-AN-184]-A UBL accounting note should not include the AccountingSupplierParty Party PartyLegalEntity FullyPaidSharesIndicator</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress)"
                 flag="warning"
                 id="UBL-AN-185">[UBL-AN-185]-A UBL accounting note should not include the AccountingSupplierParty Party PartyLegalEntity RegistrationAddress</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:CorporateRegistrationScheme)"
                 flag="warning"
                 id="UBL-AN-186">[UBL-AN-186]-A UBL accounting note should not include the AccountingSupplierParty Party PartyLegalEntity CorporateRegistrationScheme</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:HeadOfficeParty)"
                 flag="warning"
                 id="UBL-AN-187">[UBL-AN-187]-A UBL accounting note should not include the AccountingSupplierParty Party PartyLegalEntity HeadOfficeParty</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:ShareholderParty)"
                 flag="warning"
                 id="UBL-AN-188">[UBL-AN-188]-A UBL accounting note should not include the AccountingSupplierParty Party PartyLegalEntity ShareholderParty</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:Contact/cbc:ID)"
                 flag="warning"
                 id="UBL-AN-189">[UBL-AN-189]-A UBL accounting note should not include the AccountingSupplierParty Party Contact ID</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:Contact/cbc:Telefax)"
                 flag="warning"
                 id="UBL-AN-190">[UBL-AN-190]-A UBL accounting note should not include the AccountingSupplierParty Party Contact Telefax</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:Contact/cbc:Note)"
                 flag="warning"
                 id="UBL-AN-191">[UBL-AN-191]-A UBL accounting note should not include the AccountingSupplierParty Party Contact Note</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:Contact/cac:OtherCommunication)"
                 flag="warning"
                 id="UBL-AN-192">[UBL-AN-192]-A UBL accounting note should not include the AccountingSupplierParty Party Contact OtherCommunication</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:Person)"
                 flag="warning"
                 id="UBL-AN-193">[UBL-AN-193]-A UBL accounting note should not include the AccountingSupplierParty Party Person</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:AgentParty)"
                 flag="warning"
                 id="UBL-AN-194">[UBL-AN-194]-A UBL accounting note should not include the AccountingSupplierParty Party AgentParty</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:ServiceProviderParty)"
                 flag="warning"
                 id="UBL-AN-195">[UBL-AN-195]-A UBL accounting note should not include the AccountingSupplierParty Party ServiceProviderParty</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PowerOfAttorney)"
                 flag="warning"
                 id="UBL-AN-196">[UBL-AN-196]-A UBL accounting note should not include the AccountingSupplierParty Party PowerOfAttorney</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:Party/cac:FinancialAccount)"
                 flag="warning"
                 id="UBL-AN-197">[UBL-AN-197]-A UBL accounting note should not include the AccountingSupplierParty Party FinancialAccount</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:DespatchContact)"
                 flag="warning"
                 id="UBL-AN-198">[UBL-AN-198]-A UBL accounting note should not include the AccountingSupplierParty DespatchContact</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:AccountingContact)"
                 flag="warning"
                 id="UBL-AN-199">[UBL-AN-199]-A UBL accounting note should not include the AccountingSupplierParty AccountingContact</assert>
         <assert test="not(cac:AccountingSupplierParty/cac:SellerContact)"
                 flag="warning"
                 id="UBL-AN-200">[UBL-AN-200]-A UBL accounting note should not include the AccountingSupplierParty SellerContact</assert>
         <assert test="not(cac:AccountingCustomerParty/cbc:CustomerAssignedAccountID)"
                 flag="warning"
                 id="UBL-AN-201">[UBL-AN-201]-A UBL accounting note should not include the AccountingCustomerParty CustomerAssignedAccountID</assert>
         <assert test="not(cac:AccountingCustomerParty/cbc:SupplierAssignedAccountID)"
                 flag="warning"
                 id="UBL-AN-202">[UBL-AN-202]-A UBL accounting note should not include the AccountingCustomerParty SupplierAssignedAccountID</assert>
         <assert test="not(cac:AccountingCustomerParty/cbc:AdditionalAccountID)"
                 flag="warning"
                 id="UBL-AN-203">[UBL-AN-203]-A UBL accounting note should not include the AccountingCustomerParty AdditionalAccountID</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cbc:MarkCareIndicator)"
                 flag="warning"
                 id="UBL-AN-204">[UBL-AN-204]-A UBL accounting note should not include the AccountingCustomerParty Party MarkCareIndicator</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cbc:MarkAttentionIndicator)"
                 flag="warning"
                 id="UBL-AN-205">[UBL-AN-205]-A UBL accounting note should not include the AccountingCustomerParty Party MarkAttentionIndicator</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cbc:WebsiteURI)"
                 flag="warning"
                 id="UBL-AN-206">[UBL-AN-206]-A UBL accounting note should not include the AccountingCustomerParty Party WebsiteURI</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cbc:LogoReferenceID)"
                 flag="warning"
                 id="UBL-AN-207">[UBL-AN-207]-A UBL accounting note should not include the AccountingCustomerParty Party LogoReferenceID</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cbc:IndustryClassificationCode)"
                 flag="warning"
                 id="UBL-AN-208">[UBL-AN-208]-A UBL accounting note should not include the AccountingCustomerParty Party IndustryClassificationCode</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:Language)"
                 flag="warning"
                 id="UBL-AN-209">[UBL-AN-209]-A UBL accounting note should not include the AccountingCustomerParty Party Language</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:ID)"
                 flag="warning"
                 id="UBL-AN-210">[UBL-AN-210]-A UBL accounting note should not include the AccountingCustomerParty Party PostalAddress ID</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:AddressTypeCode)"
                 flag="warning"
                 id="UBL-AN-211">[UBL-AN-211]-A UBL accounting note should not include the AccountingCustomerParty Party PostalAddress AddressTypeCode</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:AddressFormatCode)"
                 flag="warning"
                 id="UBL-AN-212">[UBL-AN-212]-A UBL accounting note should not include the AccountingCustomerParty Party PostalAddress AddressFormatCode</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:Postbox)"
                 flag="warning"
                 id="UBL-AN-213">[UBL-AN-213]-A UBL accounting note should not include the AccountingCustomerParty Party PostalAddress Postbox</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:Floor)"
                 flag="warning"
                 id="UBL-AN-214">[UBL-AN-214]-A UBL accounting note should not include the AccountingCustomerParty Party PostalAddress Floor</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:Room)"
                 flag="warning"
                 id="UBL-AN-215">[UBL-AN-215]-A UBL accounting note should not include the AccountingCustomerParty Party PostalAddress Room</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:BlockName)"
                 flag="warning"
                 id="UBL-AN-216">[UBL-AN-216]-A UBL accounting note should not include the AccountingCustomerParty Party PostalAddress BlockName</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:BuildingName)"
                 flag="warning"
                 id="UBL-AN-217">[UBL-AN-217]-A UBL accounting note should not include the AccountingCustomerParty Party PostalAddress BuildingName</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:BuildingNumber)"
                 flag="warning"
                 id="UBL-AN-218">[UBL-AN-218]-A UBL accounting note should not include the AccountingCustomerParty Party PostalAddress BuildingNumber</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:InhouseMail)"
                 flag="warning"
                 id="UBL-AN-219">[UBL-AN-219]-A UBL accounting note should not include the AccountingCustomerParty Party PostalAddress InhouseMail</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:Department)"
                 flag="warning"
                 id="UBL-AN-220">[UBL-AN-220]-A UBL accounting note should not include the AccountingCustomerParty Party PostalAddress Department</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:MarkAttention)"
                 flag="warning"
                 id="UBL-AN-221">[UBL-AN-221]-A UBL accounting note should not include the AccountingCustomerParty Party PostalAddress MarkAttention</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:MarkCare)"
                 flag="warning"
                 id="UBL-AN-222">[UBL-AN-222]-A UBL accounting note should not include the AccountingCustomerParty Party PostalAddress MarkCare</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:PlotIdentification)"
                 flag="warning"
                 id="UBL-AN-223">[UBL-AN-223]-A UBL accounting note should not include the AccountingCustomerParty Party PostalAddress PlotIdentification</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:CitySubdivisionName)"
                 flag="warning"
                 id="UBL-AN-224">[UBL-AN-224]-A UBL accounting note should not include the AccountingCustomerParty Party PostalAddress CitySubdivisionName</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:CountrySubentityCode)"
                 flag="warning"
                 id="UBL-AN-225">[UBL-AN-225]-A UBL accounting note should not include the AccountingCustomerParty Party PostalAddress CountrySubentityCode</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:Region)"
                 flag="warning"
                 id="UBL-AN-226">[UBL-AN-226]-A UBL accounting note should not include the AccountingCustomerParty Party PostalAddress Region</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:District)"
                 flag="warning"
                 id="UBL-AN-227">[UBL-AN-227]-A UBL accounting note should not include the AccountingCustomerParty Party PostalAddress District</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:TimezoneOffset)"
                 flag="warning"
                 id="UBL-AN-228">[UBL-AN-228]-A UBL accounting note should not include the AccountingCustomerParty Party PostalAddress TimezoneOffset</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cac:Country/cbc:Name)"
                 flag="warning"
                 id="UBL-AN-229">[UBL-AN-229]-A UBL accounting note should not include the AccountingCustomerParty Party PostalAddress Country Name</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cac:LocationCoordinate)"
                 flag="warning"
                 id="UBL-AN-230">[UBL-AN-230]-A UBL accounting note should not include the AccountingCustomerParty Party PostalAddress LocationCoordinate</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PhysicalLocation)"
                 flag="warning"
                 id="UBL-AN-231">[UBL-AN-231]-A UBL accounting note should not include the AccountingCustomerParty Party PhysicalLocation</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyTaxScheme/cbc:RegistrationName)"
                 flag="warning"
                 id="UBL-AN-232">[UBL-AN-232]-A UBL accounting note should not include the AccountingCustomerParty Party PartyTaxScheme RegistrationName</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyTaxScheme/cbc:TaxLevelCode)"
                 flag="warning"
                 id="UBL-AN-233">[UBL-AN-233]-A UBL accounting note should not include the AccountingCustomerParty Party PartyTaxScheme TaxLevelCode</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyTaxScheme/cbc:ExemptionReasonCode)"
                 flag="warning"
                 id="UBL-AN-234">[UBL-AN-234]-A UBL accounting note should not include the AccountingCustomerParty Party PartyTaxScheme ExemptionReasonCode</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyTaxScheme/cbc:ExemptionReason)"
                 flag="warning"
                 id="UBL-AN-235">[UBL-AN-235]-A UBL accounting note should not include the AccountingCustomerParty Party PartyTaxScheme ExemptionReason</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyTaxScheme/cac:RegistrationAddress)"
                 flag="warning"
                 id="UBL-AN-236">[UBL-AN-236]-A UBL accounting note should not include the AccountingCustomerParty Party PartyTaxScheme RegistrationAddress</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyTaxScheme/cac:TaxScheme/cbc:Name)"
                 flag="warning"
                 id="UBL-AN-237">[UBL-AN-237]-A UBL accounting note should not include the AccountingCustomerParty Party PartyTaxScheme TaxScheme Name</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyTaxScheme/cac:TaxScheme/cbc:TaxTypeCode)"
                 flag="warning"
                 id="UBL-AN-238">[UBL-AN-238]-A UBL accounting note should not include the AccountingCustomerParty Party PartyTaxScheme TaxScheme TaxTypeCode</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyTaxScheme/cac:TaxScheme/cbc:CurrencyCode)"
                 flag="warning"
                 id="UBL-AN-239">[UBL-AN-239]-A UBL accounting note should not include the AccountingCustomerParty Party PartyTaxScheme TaxScheme CurrencyCode</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyTaxScheme/cac:TaxScheme/cac:JurisdictionRegionAddress)"
                 flag="warning"
                 id="UBL-AN-240">[UBL-AN-240]-A UBL accounting note should not include the AccountingCustomerParty Party PartyTaxScheme TaxScheme JurisdictionRegionAddress</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cbc:RegistrationDate)"
                 flag="warning"
                 id="UBL-AN-241">[UBL-AN-241]-A UBL accounting note should not include the AccountingCustomerParty Party PartyLegalEntity RegistrationDate</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cbc:RegistrationExpirationDate)"
                 flag="warning"
                 id="UBL-AN-242">[UBL-AN-242]-A UBL accounting note should not include the AccountingCustomerParty Party PartyLegalEntity RegistrationExpirationDate</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cbc:CompanyLegalFormCode)"
                 flag="warning"
                 id="UBL-AN-243">[UBL-AN-243]-A UBL accounting note should not include the AccountingCustomerParty Party PartyLegalEntity CompanyLegalFormCode</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cbc:CompanyLegalForm)"
                 flag="warning"
                 id="UBL-AN-244">[UBL-AN-244]-A UBL accounting note should not include the AccountingCustomerParty Party PartyLegalEntity CompanyLegalForm</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cbc:SoleProprietorshipIndicator)"
                 flag="warning"
                 id="UBL-AN-245">[UBL-AN-245]-A UBL accounting note should not include the AccountingCustomerParty Party PartyLegalEntity SoleProprietorshipIndicator</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cbc:CompanyLiquidationStatusCode)"
                 flag="warning"
                 id="UBL-AN-246">[UBL-AN-246]-A UBL accounting note should not include the AccountingCustomerParty Party PartyLegalEntity CompanyLiquidationStatusCode</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cbc:CorporationStockAmount)"
                 flag="warning"
                 id="UBL-AN-247">[UBL-AN-247]-A UBL accounting note should not include the AccountingCustomerParty Party PartyLegalEntity CorporationStockAmount</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cbc:FullyPaidSharesIndicator)"
                 flag="warning"
                 id="UBL-AN-248">[UBL-AN-248]-A UBL accounting note should not include the AccountingCustomerParty Party PartyLegalEntity FullyPaidSharesIndicator</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress)"
                 flag="warning"
                 id="UBL-AN-249">[UBL-AN-249]-A UBL accounting note should not include the AccountingCustomerParty Party PartyLegalEntity RegistrationAddress</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:CorporateRegistrationScheme)"
                 flag="warning"
                 id="UBL-AN-250">[UBL-AN-250]-A UBL accounting note should not include the AccountingCustomerParty Party PartyLegalEntity CorporateRegistrationScheme</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:HeadOfficeParty)"
                 flag="warning"
                 id="UBL-AN-251">[UBL-AN-251]-A UBL accounting note should not include the AccountingCustomerParty Party PartyLegalEntity HeadOfficeParty</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:ShareholderParty)"
                 flag="warning"
                 id="UBL-AN-252">[UBL-AN-252]-A UBL accounting note should not include the AccountingCustomerParty Party PartyLegalEntity ShareholderParty</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:Contact/cbc:ID)"
                 flag="warning"
                 id="UBL-AN-253">[UBL-AN-253]-A UBL accounting note should not include the AccountingCustomerParty Party Contact ID</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:Contact/cbc:Telefax)"
                 flag="warning"
                 id="UBL-AN-254">[UBL-AN-254]-A UBL accounting note should not include the AccountingCustomerParty Party Contact Telefax</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:Contact/cbc:Note)"
                 flag="warning"
                 id="UBL-AN-255">[UBL-AN-255]-A UBL accounting note should not include the AccountingCustomerParty Party Contact Note</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:Contact/cac:OtherCommunication)"
                 flag="warning"
                 id="UBL-AN-256">[UBL-AN-256]-A UBL accounting note should not include the AccountingCustomerParty Party Contact OtherCommunication</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:Person)"
                 flag="warning"
                 id="UBL-AN-257">[UBL-AN-257]-A UBL accounting note should not include the AccountingCustomerParty Party Person</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:AgentParty)"
                 flag="warning"
                 id="UBL-AN-258">[UBL-AN-258]-A UBL accounting note should not include the AccountingCustomerParty Party AgentParty</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:ServiceProviderParty)"
                 flag="warning"
                 id="UBL-AN-259">[UBL-AN-259]-A UBL accounting note should not include the AccountingCustomerParty Party ServiceProviderParty</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PowerOfAttorney)"
                 flag="warning"
                 id="UBL-AN-260">[UBL-AN-260]-A UBL accounting note should not include the AccountingCustomerParty Party PowerOfAttorney</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:Party/cac:FinancialAccount)"
                 flag="warning"
                 id="UBL-AN-261">[UBL-AN-261]-A UBL accounting note should not include the AccountingCustomerParty Party FinancialAccount</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:DeliveryContact)"
                 flag="warning"
                 id="UBL-AN-262">[UBL-AN-262]-A UBL accounting note should not include the AccountingCustomerParty DeliveryContact</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:AccountingContact)"
                 flag="warning"
                 id="UBL-AN-263">[UBL-AN-263]-A UBL accounting note should not include the AccountingCustomerParty AccountingContact</assert>
         <assert test="not(cac:AccountingCustomerParty/cac:BuyerContact)"
                 flag="warning"
                 id="UBL-AN-264">[UBL-AN-264]-A UBL accounting note should not include the AccountingCustomerParty BuyerContact</assert>
         <assert test="not(cac:PayeeParty)"
                 flag="warning"
                 id="UBL-AN-265">[UBL-AN-265]-A UBL accounting note should not include the PayeeParty</assert>
         <assert test="not(cac:BuyerCustomerParty)" flag="warning" id="UBL-AN-294">[UBL-AN-294]-A UBL accounting note should not include the BuyerCustomerParty</assert>
         <assert test="not(cac:SellerCustomerParty)" flag="warning" id="UBL-AN-295">[UBL-AN-295]-A UBL accounting note should not include the SellerCustomerParty</assert>
         <assert test="not(cac:TaxRepresentativeParty)"
                 flag="warning"
                 id="UBL-AN-296">[UBL-AN-296]-A UBL accounting note should not include the TaxRepresentativeParty</assert>
         <assert test="not(cac:Delivery)" flag="warning" id="UBL-AN-342">[UBL-AN-342]-A UBL accounting note should not include the Delivery</assert>
         <assert test="not(cac:DeliveryTerms)" flag="warning" id="UBL-AN-410">[UBL-AN-410]-A UBL accounting note should not include the DeliveryTerms</assert>
         <assert test="not(cac:PaymentMeans)" flag="warning" id="UBL-AN-411">[UBL-AN-411]-A UBL accounting note should not include the PaymentMeans</assert>
         <assert test="not(cac:PaymentTerms/cbc:ID)" flag="warning" id="UBL-AN-452">[UBL-AN-452]-A UBL accounting note should not include the PaymentTerms ID</assert>
         <assert test="not(cac:PaymentTerms)"
                 flag="warning"
                 id="UBL-AN-453">[UBL-AN-453]-A UBL accounting note should not include the PaymentTerms</assert>
         <assert test="not(cac:PrepaidPayment)" flag="warning" id="UBL-AN-470">[UBL-AN-470]-A UBL accounting note should not include the PrepaidPayment</assert>
         <assert test="not(cac:AllowanceCharge)"
                 flag="warning"
                 id="UBL-AN-471">[UBL-AN-471]-A UBL accounting note should not include the AllowanceCharge</assert>
         <assert test="not(cac:TaxExchangeRate)" flag="warning" id="UBL-AN-490">[UBL-AN-490]-A UBL accounting note should not include the TaxExchangeRate</assert>
         <assert test="not(cac:PricingExchangeRate)" flag="warning" id="UBL-AN-491">[UBL-AN-491]-A UBL accounting note should not include the PricingExchangeRate</assert>
         <assert test="not(cac:PaymentExchangeRate)" flag="warning" id="UBL-AN-492">[UBL-AN-492]-A UBL accounting note should not include the PaymentExchangeRate</assert>
         <assert test="not(cac:PaymentAlternativeExchangeRate)"
                 flag="warning"
                 id="UBL-AN-493">[UBL-AN-493]-A UBL accounting note should not include the PaymentAlternativeExchangeRate</assert>
         <assert test="not(cac:TaxTotal)"
                 flag="warning"
                 id="UBL-AN-494">[UBL-AN-494]-A UBL accounting note should not include the TaxTotal</assert>
         <assert test="not(cac:WithholdingTaxTotal)" flag="warning" id="UBL-AN-513">[UBL-AN-513]-A UBL accounting note should not include the WithholdingTaxTotal</assert>
         <assert test="not(cac:LegalMonetaryTotal/cbc:PayableAlternativeAmount)"
                 flag="warning"
                 id="UBL-AN-514-1">[UBL-AN-514-1]-A UBL accounting note should not include the LegalMonetaryTotal PayableAlternativeAmount</assert>
         <assert test="not(cac:LegalMonetaryTotal/cbc:TaxExclusiveAmount)"
                 flag="warning"
                 id="UBL-AN-514-2">[UBL-AN-514-2]-A UBL accounting note should not include the LegalMonetaryTotal TaxExclusiveAmount</assert>
         <assert test="not(cac:LegalMonetaryTotal/cbc:TaxInclusiveAmount)"
                 flag="warning"
                 id="UBL-AN-514-3">[UBL-AN-514-3]-A UBL accounting note should not include the LegalMonetaryTotal TaxInclusiveAmount</assert>
         <assert test="not(cac:LegalMonetaryTotal/cbc:AllowanceTotalAmount)"
                 flag="warning"
                 id="UBL-AN-514-4">[UBL-AN-514-4]-A UBL accounting note should not include the LegalMonetaryTotal AllowanceTotalAmount</assert>
         <assert test="not(cac:LegalMonetaryTotal/cbc:ChargeTotalAmount)"
                 flag="warning"
                 id="UBL-AN-514-5">[UBL-AN-514-5]-A UBL accounting note should not include the LegalMonetaryTotal ChargeTotalAmount</assert>
         <assert test="not(cac:LegalMonetaryTotal/cbc:PrepaidAmount)"
                 flag="warning"
                 id="UBL-AN-514-6">[UBL-AN-514-6]-A UBL accounting note should not include the LegalMonetaryTotal PrepaidAmount</assert>
         <assert test="not(cac:LegalMonetaryTotal/cbc:PayableRoundingAmount)"
                 flag="warning"
                 id="UBL-AN-514-7">[UBL-AN-514-7]-A UBL accounting note should not include the LegalMonetaryTotal PayableRoundingAmount</assert>
         <assert test="not(cac:InvoiceLine/cbc:UUID)" flag="warning" id="UBL-AN-515">[UBL-AN-515]-A UBL accounting note should not include the InvoiceLine UUID</assert>
         <assert test="not(cac:InvoiceLine/cbc:TaxPointDate)"
                 flag="warning"
                 id="UBL-AN-516">[UBL-AN-516]-A UBL accounting note should not include the InvoiceLine TaxPointDate</assert>
         <assert test="not(cac:InvoiceLine/cbc:AccountingCostCode)"
                 flag="warning"
                 id="UBL-AN-517">[UBL-AN-517]-A UBL accounting note should not include the InvoiceLine AccountingCostCode</assert>
         <assert test="not(cac:InvoiceLine/cbc:PaymentPurposeCode)"
                 flag="warning"
                 id="UBL-AN-518">[UBL-AN-518]-A UBL accounting note should not include the InvoiceLine PaymentPurposeCode</assert>
         <assert test="not(cac:InvoiceLine/cbc:FreeOfChargeIndicator)"
                 flag="warning"
                 id="UBL-AN-519">[UBL-AN-519]-A UBL accounting note should not include the InvoiceLine FreeOfChargeIndicator</assert>
         <assert test="not(cac:InvoiceLine/cac:InvoicePeriod)"
                 flag="warning"
                 id="UBL-AN-520">[UBL-AN-520]-A UBL accounting note should not include the InvoiceLine InvoicePeriod</assert>
         <assert test="not(cac:InvoiceLine/cac:InvoicedQuantity)"
                 flag="warning"
                 id="UBL-AN-521">[UBL-AN-521]-A UBL accounting note should not include the InvoiceLine InvoicedQuantity</assert>
         <assert test="not(cac:InvoiceLine/cac:AllowanceCharge)"
                 flag="warning"
                 id="UBL-AN-522">[UBL-AN-522]-A UBL accounting note should not include the InvoiceLine AllowanceCharge</assert>
         <assert test="not(cac:InvoiceLine/cac:OrderLineReference)"
                 flag="warning"
                 id="UBL-AN-525">[UBL-AN-525]-A UBL accounting note should not include the InvoiceLine OrderLineReference SalesOrderLineID</assert>
         <assert test="not(cac:InvoiceLine/cac:DespatchLineReference)"
                 flag="warning"
                 id="UBL-AN-529">[UBL-AN-529]-A UBL accounting note should not include the InvoiceLine DespatchLineReference</assert>
         <assert test="not(cac:InvoiceLine/cac:ReceiptLineReference)"
                 flag="warning"
                 id="UBL-AN-530">[UBL-AN-530]-A UBL accounting note should not include the InvoiceLine ReceiptLineReference</assert>
         <assert test="not(cac:InvoiceLine/cac:BillingReference)"
                 flag="warning"
                 id="UBL-AN-531">[UBL-AN-531]-A UBL accounting note should not include the InvoiceLine BillingReference</assert>
         <assert test="not(cac:InvoiceLine/cac:DocumentReference)"
                 flag="warning"
                 id="UBL-AN-532">[UBL-AN-532]-A UBL accounting note should not include the InvoiceLine DocumentReference</assert>
        <assert test="not(cac:InvoiceLine/cac:PricingReference)"
                 flag="warning"
                 id="UBL-AN-548">[UBL-AN-548]-A UBL accounting note should not include the InvoiceLine PricingReference</assert>
         <assert test="not(cac:InvoiceLine/cac:OriginatorParty)"
                 flag="warning"
                 id="UBL-AN-549">[UBL-AN-549]-A UBL accounting note should not include the InvoiceLine OriginatorParty</assert>
         <assert test="not(cac:InvoiceLine/cac:Delivery)"
                 flag="warning"
                 id="UBL-AN-550">[UBL-AN-550]-A UBL accounting note should not include the InvoiceLine Delivery</assert>
         <assert test="not(cac:InvoiceLine/cac:PaymentTerms)"
                 flag="warning"
                 id="UBL-AN-551">[UBL-AN-551]-A UBL accounting note should not include the InvoiceLine PaymentTerms</assert>
         <assert test="not(cac:InvoiceLine/cac:TaxTotal)"
                 flag="warning"
                 id="UBL-AN-561">[UBL-AN-561]-A UBL accounting note should not include the InvoiceLine TaxTotal</assert>
         <assert test="not(cac:InvoiceLine/cac:WithholdingTaxTotal)"
                 flag="warning"
                 id="UBL-AN-562">[UBL-AN-562]-A UBL accounting note should not include the InvoiceLine WithholdingTaxTotal</assert>
         <assert test="not(cac:InvoiceLine/cac:Item)"
                 flag="warning"
                 id="UBL-AN-563">[UBL-AN-563]-A UBL accounting note should not include the InvoiceLine Item</assert>
         <assert test="not(cac:InvoiceLine/cac:Item/cac:Price)"
                 flag="warning"
                 id="UBL-AN-644">[UBL-AN-644]-A UBL accounting note should not include the InvoiceLine Item Price</assert>
         <assert test="not(cac:InvoiceLine/cac:DeliveryTerms)"
                 flag="warning"
                 id="UBL-AN-645">[UBL-AN-645]-A UBL accounting note should not include the InvoiceLine DeliveryTerms</assert>
         <assert test="not(cac:InvoiceLine/cac:SubInvoiceLine)"
                 flag="warning"
                 id="UBL-AN-646">[UBL-AN-646]-A UBL accounting note should not include the InvoiceLine SubInvoiceLine</assert>
         <assert test="not(cac:InvoiceLine/cac:ItemPriceExtension)"
                 flag="warning"
                 id="UBL-AN-647">[UBL-AN-647]-A UBL accounting note should not include the InvoiceLine ItemPriceExtension</assert>
        
         <assert test="not(//@schemeName)" flag="warning" id="UBL-AN-701">[UBL-AN-701]-Scheme name attribute should not be present</assert>
         <assert test="not(//@schemeAgencyName)" flag="warning" id="UBL-AN-702">[UBL-AN-702]-Scheme agency name attribute should not be present</assert>
         <assert test="not(//@schemeDataURI)" flag="warning" id="UBL-AN-703">[UBL-AN-703]-Scheme data uri attribute should not be present</assert>
         <assert test="not(//@schemeURI)" flag="warning" id="UBL-AN-704">[UBL-AN-704]-Scheme uri attribute should not be present</assert>
         <assert test="not(//@format)" flag="warning" id="UBL-AN-705">[UBL-AN-705]-Format attribute should not be present</assert>
         <assert test="not(//@unitCodeListIdentifier)" flag="warning" id="UBL-AN-706">[UBL-AN-706]-Unit code list identifier attribute should not be present</assert>
         <assert test="not(//@unitCodeListAgencyIdentifier)"
                 flag="warning"
                 id="UBL-AN-707">[UBL-AN-707]-Unit code list agency identifier attribute should not be present</assert>
         <assert test="not(//@unitCodeListAgencyName)" flag="warning" id="UBL-AN-708">[UBL-AN-708]-Unit code list agency name attribute should not be present</assert>
         <assert test="not(//@listAgencyName)" flag="warning" id="UBL-AN-709">[UBL-AN-709]-List agency name attribute should not be present</assert>
         <assert test="not(//@listName)" flag="warning" id="UBL-AN-710">[UBL-AN-710]-List name attribute should not be present</assert>
         <assert test="(count(cac:InvoicePeriod) &lt;= 1)"
                 flag="warning"
                 id="UBL-AN-711">[UBL-AN-711]-Invoice period shall occur maximum once</assert>
      </rule>
      <rule context="cac:InvoiceLine">
         <assert test="(count(cbc:Note) &lt;= 1)" flag="warning" id="UBL-AN-712">[UBL-AN-712]-Invoice line note shall occur maximum once</assert>
      </rule>      

   </pattern>

</schema>
